@@ -320,10 +320,11 @@ VALID_PROJECTIONS = {
 @options.ALL(help='Include hidden codes.')
 @options.ALL_USERS(help='Include codes from all users.')
 @options.PROJECT(type=click.Choice(VALID_PROJECTIONS.keys()), default=['full_label', 'pk', 'entry_point'])
+@options.RAW()
 @click.option('-o', '--show-owner', 'show_owner', is_flag=True, default=False, help='Show owners of codes.')
 @with_dbenv()
-def code_list(computer, default_calc_job_plugin, all_entries, all_users, show_owner, project):
-    # pylint: disable=too-many-branches
+def code_list(computer, default_calc_job_plugin, all_entries, all_users, raw, show_owner, project):
+    # pylint: disable=too-many-branches,too-many-locals
     """List the available codes."""
     from aiida import orm
     from aiida.orm.utils.node import load_node_class
@@ -379,7 +380,8 @@ def code_list(computer, default_calc_job_plugin, all_entries, all_users, show_ow
         return
 
     table = []
-    headers = [projection.replace('_', ' ').capitalize() for projection in project]
+    headers = [projection.replace('_', ' ').capitalize() for projection in project] if not raw else []
+    table_format = 'plain' if raw else None
 
     for result in query.iterdict():
         row = []
@@ -392,5 +394,7 @@ def code_list(computer, default_calc_job_plugin, all_entries, all_users, show_ow
                 row.append('@'.join(str(result[entity][projection]) for entity, projection in VALID_PROJECTIONS[key]))
         table.append(row)
 
-    echo.echo(tabulate.tabulate(table, headers=headers))
-    echo.echo_report('\nUse `verdi code show IDENTIFIER` to see details for a code', prefix=False)
+    echo.echo(tabulate.tabulate(table, headers=headers, tablefmt=table_format))
+
+    if not raw:
+        echo.echo_report('\nUse `verdi code show IDENTIFIER` to see details for a code', prefix=False)
