@@ -8,21 +8,17 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """`verdi daemon` commands."""
-
-import os
 import subprocess
-import time
 import sys
+import time
 
 import click
 from click_spinner import spinner
 
 from aiida.cmdline.commands.cmd_verdi import verdi
 from aiida.cmdline.utils import decorators, echo
-from aiida.cmdline.utils.common import get_env_with_venv_bin
-from aiida.cmdline.utils.daemon import get_daemon_status, \
-    print_client_response_status, delete_stale_pid_file, _START_CIRCUS_COMMAND
-from aiida.manage.configuration import get_config
+from aiida.cmdline.utils.daemon import delete_stale_pid_file, get_daemon_status, print_client_response_status
+from aiida.manage import get_manager
 
 
 def validate_daemon_workers(ctx, param, value):  # pylint: disable=unused-argument,invalid-name
@@ -57,25 +53,17 @@ def start(foreground, number):
 
     Returns exit code 0 if the daemon is OK, non-zero if there was an error.
     """
-    from aiida.engine.daemon.client import get_daemon_client
+    from aiida.engine.daemon.client import DaemonException, get_daemon_client
 
     client = get_daemon_client()
 
-    echo.echo('Starting the daemon... ', nl=False)
-
-    if foreground:
-        command = ['verdi', '-p', client.profile.name, 'daemon', _START_CIRCUS_COMMAND, '--foreground', str(number)]
-    else:
-        command = ['verdi', '-p', client.profile.name, 'daemon', _START_CIRCUS_COMMAND, str(number)]
-
     try:
-        currenv = get_env_with_venv_bin()
-        subprocess.check_output(command, env=currenv, stderr=subprocess.STDOUT)  # pylint: disable=unexpected-keyword-arg
-    except subprocess.CalledProcessError as exception:
-        click.secho('FAILED', fg='red', bold=True)
+        echo.echo(f'Starting the daemon with {number} workers... ', nl=False)
+        client.start_daemon(number_workers=number, foreground=foreground)
+    except DaemonException as exception:
+        echo.echo('FAILED', fg=echo.COLORS['error'], bold=True)
         echo.echo_critical(str(exception))
 
-    # We add a small timeout to give the pid-file a chance to be created
     with spinner():
         time.sleep(1)
         response = client.get_status()
@@ -94,19 +82,20 @@ def status(all_profiles):
     """
     from aiida.engine.daemon.client import get_daemon_client
 
-    config = get_config()
+    manager = get_manager()
+    config = manager.get_config()
 
     if all_profiles is True:
         profiles = [profile for profile in config.profiles if not profile.is_test_profile]
     else:
-        profiles = [config.current_profile]
+        profiles = [manager.get_profile()]
 
     daemons_running = []
     for profile in profiles:
         client = get_daemon_client(profile.name)
         delete_stale_pid_file(client)
-        click.secho('Profile: ', fg='red', bold=True, nl=False)
-        click.secho(f'{profile.name}', bold=True)
+        echo.echo('Profile: ', fg=echo.COLORS['report'], bold=True, nl=False)
+        echo.echo(f'{profile.name}', bold=True)
         result = get_daemon_status(client)
         echo.echo(result)
         daemons_running.append(client.is_daemon_running)
@@ -156,12 +145,8 @@ def logshow():
 
     client = get_daemon_client()
 
-    try:
-        currenv = get_env_with_venv_bin()
-        process = subprocess.Popen(['tail', '-f', client.daemon_log_file], env=currenv)
+    with subprocess.Popen(['tail', '-f', client.daemon_log_file], env=client.get_env()) as process:
         process.wait()
-    except KeyboardInterrupt:
-        process.kill()
 
 
 @verdi_daemon.command()
@@ -174,19 +159,20 @@ def stop(no_wait, all_profiles):
     """
     from aiida.engine.daemon.client import get_daemon_client
 
-    config = get_config()
+    manager = get_manager()
+    config = manager.get_config()
 
     if all_profiles is True:
         profiles = [profile for profile in config.profiles if not profile.is_test_profile]
     else:
-        profiles = [config.current_profile]
+        profiles = [manager.get_profile()]
 
     for profile in profiles:
 
         client = get_daemon_client(profile.name)
 
-        click.secho('Profile: ', fg='red', bold=True, nl=False)
-        click.secho(f'{profile.name}', bold=True)
+        echo.echo('Profile: ', fg=echo.COLORS['report'], bold=True, nl=False)
+        echo.echo(f'{profile.name}', bold=True)
 
         if not client.is_daemon_running:
             echo.echo('Daemon was not running')
@@ -205,7 +191,7 @@ def stop(no_wait, all_profiles):
 
         if wait:
             if response['status'] == client.DAEMON_ERROR_NOT_RUNNING:
-                click.echo('The daemon was not running.')
+                echo.echo('The daemon was not running.')
             else:
                 retcode = print_client_response_status(response)
                 if retcode:
@@ -230,7 +216,6 @@ def restart(ctx, reset, no_wait):
     from aiida.engine.daemon.client import get_daemon_client
 
     client = get_daemon_client()
-
     wait = not no_wait
 
     if reset:
@@ -268,84 +253,13 @@ def start_circus(foreground, number):
 
     .. note:: this should not be called directly from the commandline!
     """
-    from circus import get_arbiter
-    from circus import logger as circus_logger
-    from circus.circusd import daemonize
-    from circus.pidfile import Pidfile
-    from circus.util import check_future_exception_and_log, configure_logger
-
     from aiida.engine.daemon.client import get_daemon_client
+    get_daemon_client()._start_daemon(number_workers=number, foreground=foreground)  # pylint: disable=protected-access
 
-    if foreground and number > 1:
-        raise click.ClickException('can only run a single worker when running in the foreground')
 
-    client = get_daemon_client()
-
-    loglevel = client.loglevel
-    logoutput = '-'
-
-    if not foreground:
-        logoutput = client.circus_log_file
-
-    arbiter_config = {
-        'controller': client.get_controller_endpoint(),
-        'pubsub_endpoint': client.get_pubsub_endpoint(),
-        'stats_endpoint': client.get_stats_endpoint(),
-        'logoutput': logoutput,
-        'loglevel': loglevel,
-        'debug': False,
-        'statsd': True,
-        'pidfile': client.circus_pid_file,
-        'watchers': [{
-            'cmd': client.cmd_string,
-            'name': client.daemon_name,
-            'numprocesses': number,
-            'virtualenv': client.virtualenv,
-            'copy_env': True,
-            'stdout_stream': {
-                'class': 'FileStream',
-                'filename': client.daemon_log_file,
-            },
-            'stderr_stream': {
-                'class': 'FileStream',
-                'filename': client.daemon_log_file,
-            },
-            'env': get_env_with_venv_bin(),
-        }]
-    }  # yapf: disable
-
-    if not foreground:
-        daemonize()
-
-    arbiter = get_arbiter(**arbiter_config)
-    pidfile = Pidfile(arbiter.pidfile)
-
-    try:
-        pidfile.create(os.getpid())
-    except RuntimeError as exception:
-        echo.echo_critical(str(exception))
-
-    # Configure the logger
-    loggerconfig = None
-    loggerconfig = loggerconfig or arbiter.loggerconfig or None
-    configure_logger(circus_logger, loglevel, logoutput, loggerconfig)
-
-    # Main loop
-    should_restart = True
-
-    while should_restart:
-        try:
-            future = arbiter.start()
-            should_restart = False
-            if check_future_exception_and_log(future) is None:
-                should_restart = arbiter._restarting  # pylint: disable=protected-access
-        except Exception as exception:
-            # Emergency stop
-            arbiter.loop.run_sync(arbiter._emergency_stop)  # pylint: disable=protected-access
-            raise exception
-        except KeyboardInterrupt:
-            pass
-        finally:
-            arbiter = None
-            if pidfile is not None:
-                pidfile.unlink()
+@verdi_daemon.command('worker')
+@decorators.with_dbenv()
+def worker():
+    """Run a single daemon worker in the current interpreter."""
+    from aiida.engine.daemon.worker import start_daemon_worker
+    start_daemon_worker()
