@@ -41,7 +41,7 @@ class WithNonDb:
     def __init__(self, *args, **kwargs) -> None:
         self._non_db_explicitly_set: bool = bool('non_db' in kwargs)
         non_db = kwargs.pop('non_db', False)
-        super().__init__(*args, **kwargs)  # type: ignore[call-arg]
+        super().__init__(*args, **kwargs)
         self._non_db: bool = non_db
 
     @property
@@ -76,16 +76,16 @@ class WithSerialize:
 
     def __init__(self, *args, **kwargs) -> None:
         serializer = kwargs.pop('serializer', None)
-        super().__init__(*args, **kwargs)  # type: ignore[call-arg]
+        super().__init__(*args, **kwargs)
         self._serializer: Callable[[Any], 'Data'] = serializer
 
     def serialize(self, value: Any) -> 'Data':
-        """Serialize the given value if it is not already a Data type and a serializer function is defined
+        """Serialize the given value, unless it is ``None``, already a Data type, or no serializer function is defined.
 
         :param value: the value to be serialized
         :returns: a serialized version of the value or the unchanged value
         """
-        if self._serializer is None or isinstance(value, Data):
+        if self._serializer is None or value is None or isinstance(value, Data):
             return value
 
         return self._serializer(value)
@@ -109,7 +109,16 @@ class InputPort(WithSerialize, WithNonDb, ports.InputPort):
                     ' It is advised to use a lambda instead, e.g.: `default=lambda: orm.Int(5)`.'.format(args[0])
                 warnings.warn(UserWarning(message))  # pylint: disable=no-member
 
-        super(InputPort, self).__init__(*args, **kwargs)
+        # If the port is not required and defines ``valid_type``, automatically add ``None`` as a valid type
+        valid_type = kwargs.get('valid_type', ())
+
+        if not isinstance(valid_type, (tuple, list)):
+            valid_type = [valid_type]
+
+        if not kwargs.get('required', True) and valid_type:
+            kwargs['valid_type'] = tuple(valid_type) + (type(None),)
+
+        super().__init__(*args, **kwargs)
 
     def get_description(self) -> Dict[str, str]:
         """
@@ -189,7 +198,7 @@ class PortNamespace(WithNonDb, ports.PortNamespace):
         # `('___', '_')`, where the first element is the matched group of consecutive underscores.
         consecutive_underscores = [match[0] for match in re.findall(r'((_)\2+)', port_name)]
 
-        if any([len(entry) > PORT_NAME_MAX_CONSECUTIVE_UNDERSCORES for entry in consecutive_underscores]):
+        if any(len(entry) > PORT_NAME_MAX_CONSECUTIVE_UNDERSCORES for entry in consecutive_underscores):
             raise ValueError(f'invalid port name `{port_name}`: more than two consecutive underscores')
 
     def serialize(self, mapping: Optional[Dict[str, Any]], breadcrumbs: Sequence[str] = ()) -> Optional[Dict[str, Any]]:
