@@ -7,6 +7,7 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
+# pylint: disable=too-many-lines
 """The AiiDA process class"""
 import asyncio
 import collections
@@ -218,7 +219,6 @@ class Process(plumpy.processes.Process):
         """Return the ProcessNode used by this process to represent itself in the database.
 
         :return: instance of sub class of ProcessNode
-
         """
         assert self._node is not None
         return self._node
@@ -309,7 +309,7 @@ class Process(plumpy.processes.Process):
         super().load_instance_state(saved_state, load_context)
 
         if self.SaveKeys.CALC_ID.value in saved_state:
-            self._node = orm.load_node(saved_state[self.SaveKeys.CALC_ID.value])
+            self._node = orm.load_node(saved_state[self.SaveKeys.CALC_ID.value])  # type: ignore
             self._pid = self.node.pk  # pylint: disable=attribute-defined-outside-init
         else:
             self._pid = self._create_and_setup_db_record()  # pylint: disable=attribute-defined-outside-init
@@ -347,7 +347,7 @@ class Process(plumpy.processes.Process):
 
             if asyncio.isfuture(result):
                 # We ourselves are waiting to be killed so add it to the list
-                killing.append(result)  # type: ignore[arg-type]
+                killing.append(result)
 
             if killing:
                 # We are waiting for things to be killed, so return the 'gathered' future
@@ -401,15 +401,24 @@ class Process(plumpy.processes.Process):
         self._pid = self._create_and_setup_db_record()  # pylint: disable=attribute-defined-outside-init
 
     @override
-    def on_entering(self, state: plumpy.process_states.State) -> None:
-        super().on_entering(state)
-        # Update the node attributes every time we enter a new state
-
     def on_entered(self, from_state: Optional[plumpy.process_states.State]) -> None:
         """After entering a new state, save a checkpoint and update the latest process state change timestamp."""
         # pylint: disable=cyclic-import
         from aiida.engine.utils import set_process_state_change_timestamp
-        self.update_node_state(self._state)
+
+        # For reasons unknown, it is important to update the outputs first, before doing anything else, otherwise there
+        # is the risk that certain outputs do not get attached before the process reaches a terminal state. Nevertheless
+        # we need to guarantee that the process state gets updated even if the ``update_outputs`` call excepts, for
+        # example if the process implementation attaches an invalid output through ``Process.out``, and so we call the
+        # ``ProcessNode.set_process_state`` in the finally-clause. This way the state gets properly set on the node even
+        # if the process is transitioning to the terminal excepted state.
+        try:
+            self.update_outputs()
+        except ValueError:  # pylint: disable=try-except-raise
+            raise
+        finally:
+            self.node.set_process_state(self._state.LABEL)  # type: ignore
+
         self._save_checkpoint()
         set_process_state_change_timestamp(self)
         super().on_entered(from_state)
@@ -538,7 +547,7 @@ class Process(plumpy.processes.Process):
         if self._parent_pid is None:
             return None
 
-        return orm.load_node(pk=self._parent_pid)
+        return orm.load_node(pk=self._parent_pid)  # type: ignore
 
     @classmethod
     def build_process_type(cls) -> str:
@@ -633,10 +642,6 @@ class Process(plumpy.processes.Process):
         """
         return serialize.deserialize_unsafe(encoded)
 
-    def update_node_state(self, state: plumpy.process_states.State) -> None:
-        self.update_outputs()
-        self.node.set_process_state(state.LABEL)
-
     def update_outputs(self) -> None:
         """Attach new outputs to the node since the last call.
 
@@ -707,13 +712,28 @@ class Process(plumpy.processes.Process):
                 self.node.base.links.add_incoming(parent_calc, LinkType.CALL_WORK, self.metadata.call_link_label)
 
         self._setup_metadata(copy.copy(dict(self.inputs.metadata)))
+        self._setup_version_info()
         self._setup_inputs()
 
+    def _setup_version_info(self) -> None:
+        """Store relevant plugin version information."""
+        from aiida.plugins.entry_point import format_entry_point_string
+
+        if self.inputs is None:
+            return
+
+        version_info = self.runner.plugin_version_provider.get_version_info(self.__class__)
+
+        for key, monitor in self.inputs.get('monitors', {}).items():
+            entry_point = monitor.base.attributes.get('entry_point')
+            entry_point_string = format_entry_point_string('aiida.calculations.monitors', entry_point)
+            monitor_version_info = self.runner.plugin_version_provider.get_version_info(entry_point_string)
+            version_info['version'].setdefault('monitors', {})[key] = monitor_version_info['version']['plugin']
+
+        self.node.base.attributes.set_many(version_info)
+
     def _setup_metadata(self, metadata: dict) -> None:
         """Store the metadata on the ProcessNode."""
-        version_info = self.runner.plugin_version_provider.get_version_info(self.__class__)
-        self.node.base.attributes.set_many(version_info)
-
         for name, value in metadata.items():
             if name in ['store_provenance', 'dry_run', 'call_link_label']:
                 continue
@@ -971,8 +991,11 @@ class Process(plumpy.processes.Process):
             codes may have no effect.
 
         """
+        exit_status = node.exit_status
+        if exit_status is None:
+            return True
         try:
-            return not cls.spec().exit_codes(node.exit_status).invalidates_cache
+            return not cls.spec().exit_codes(exit_status).invalidates_cache
         except ValueError:
             return True
 
