@@ -17,23 +17,12 @@ from typing import TYPE_CHECKING, Any, Dict, Mapping, Optional, Type
 from aiida.common import exceptions
 
 from .options import parse_option
-from .settings import DAEMON_DIR, DAEMON_LOG_DIR
 
 if TYPE_CHECKING:
     from aiida.orm.implementation import StorageBackend
 
 __all__ = ('Profile',)
 
-CIRCUS_PID_FILE_TEMPLATE = os.path.join(DAEMON_DIR, 'circus-{}.pid')
-DAEMON_PID_FILE_TEMPLATE = os.path.join(DAEMON_DIR, 'aiida-{}.pid')
-CIRCUS_LOG_FILE_TEMPLATE = os.path.join(DAEMON_LOG_DIR, 'circus-{}.log')
-DAEMON_LOG_FILE_TEMPLATE = os.path.join(DAEMON_LOG_DIR, 'aiida-{}.log')
-CIRCUS_PORT_FILE_TEMPLATE = os.path.join(DAEMON_DIR, 'circus-{}.port')
-CIRCUS_SOCKET_FILE_TEMPATE = os.path.join(DAEMON_DIR, 'circus-{}.sockets')
-CIRCUS_CONTROLLER_SOCKET_TEMPLATE = 'circus.c.sock'
-CIRCUS_PUBSUB_SOCKET_TEMPLATE = 'circus.p.sock'
-CIRCUS_STATS_SOCKET_TEMPLATE = 'circus.s.sock'
-
 
 class Profile:  # pylint: disable=too-many-public-methods
     """Class that models a profile as it is stored in the configuration file of an AiiDA instance."""
@@ -124,16 +113,8 @@ class Profile:  # pylint: disable=too-many-public-methods
     @property
     def storage_cls(self) -> Type['StorageBackend']:
         """Return the storage backend class for this profile."""
-        if self.storage_backend == 'psql_dos':
-            from aiida.storage.psql_dos.backend import PsqlDosBackend
-            return PsqlDosBackend
-        if self.storage_backend == 'sqlite_zip':
-            from aiida.storage.sqlite_zip.backend import SqliteZipBackend
-            return SqliteZipBackend
-        if self.storage_backend == 'sqlite_temp':
-            from aiida.storage.sqlite_temp.backend import SqliteTempBackend
-            return SqliteTempBackend
-        raise ValueError(f'unknown storage backend type: {self.storage_backend}')
+        from aiida.plugins import StorageFactory
+        return StorageFactory(self.storage_backend)
 
     @property
     def process_control_backend(self) -> str:
@@ -227,6 +208,10 @@ class Profile:  # pylint: disable=too-many-public-methods
         """
         from urllib.parse import urlparse
 
+        from aiida.common.warnings import warn_deprecation
+
+        warn_deprecation('This method has been deprecated', version=3)
+
         if 'repository_uri' not in self.storage_config:
             raise KeyError('repository_uri not defined in profile storage config')
 
@@ -266,20 +251,22 @@ class Profile:  # pylint: disable=too-many-public-methods
 
         :return: a dictionary of filepaths
         """
+        from .settings import DAEMON_DIR, DAEMON_LOG_DIR
+
         return {
             'circus': {
-                'log': CIRCUS_LOG_FILE_TEMPLATE.format(self.name),
-                'pid': CIRCUS_PID_FILE_TEMPLATE.format(self.name),
-                'port': CIRCUS_PORT_FILE_TEMPLATE.format(self.name),
+                'log': str(DAEMON_LOG_DIR / f'circus-{self.name}.log'),
+                'pid': str(DAEMON_DIR / f'circus-{self.name}.pid'),
+                'port': str(DAEMON_DIR / f'circus-{self.name}.port'),
                 'socket': {
-                    'file': CIRCUS_SOCKET_FILE_TEMPATE.format(self.name),
-                    'controller': CIRCUS_CONTROLLER_SOCKET_TEMPLATE,
-                    'pubsub': CIRCUS_PUBSUB_SOCKET_TEMPLATE,
-                    'stats': CIRCUS_STATS_SOCKET_TEMPLATE,
+                    'file': str(DAEMON_DIR / f'circus-{self.name}.sockets'),
+                    'controller': 'circus.c.sock',
+                    'pubsub': 'circus.p.sock',
+                    'stats': 'circus.s.sock',
                 }
             },
             'daemon': {
-                'log': DAEMON_LOG_FILE_TEMPLATE.format(self.name),
-                'pid': DAEMON_PID_FILE_TEMPLATE.format(self.name),
+                'log': str(DAEMON_LOG_DIR / f'aiida-{self.name}.log'),
+                'pid': str(DAEMON_DIR / f'aiida-{self.name}.pid'),
             }
         }
