@@ -62,7 +62,7 @@ class ComputerCollection(entities.Collection['Computer']):
         return self._backend.computers.delete(pk)
 
 
-class Computer(entities.Entity['BackendComputer']):
+class Computer(entities.Entity['BackendComputer', ComputerCollection]):
     """
     Computer entity.
     """
@@ -79,12 +79,12 @@ class Computer(entities.Entity['BackendComputer']):
 
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        label: str = None,
+        label: Optional[str] = None,
         hostname: str = '',
         description: str = '',
         transport_type: str = '',
         scheduler_type: str = '',
-        workdir: str = None,
+        workdir: Optional[str] = None,
         backend: Optional['StorageBackend'] = None,
     ) -> None:
         """Construct a new computer."""
@@ -580,6 +580,14 @@ class Computer(entities.Entity['BackendComputer']):
 
         return authinfo
 
+    @property
+    def is_configured(self) -> bool:
+        """Return whether the computer is configured for the current default user.
+
+        :return: Boolean, ``True`` if the computer is configured for the current default user, ``False`` otherwise.
+        """
+        return self.is_user_configured(users.User.collection(self.backend).get_default())
+
     def is_user_configured(self, user: 'User') -> bool:
         """
         Is the user configured on this computer?
