@@ -9,6 +9,7 @@
 ###########################################################################
 """Data plugin to represet arrays of projected wavefunction components."""
 import copy
+
 import numpy as np
 
 from aiida.common import exceptions
@@ -18,6 +19,8 @@ from ..orbital import OrbitalData
 from .array import ArrayData
 from .bands import BandsData
 
+__all__ = ('ProjectionData',)
+
 
 class ProjectionData(OrbitalData, ArrayData):
     """
@@ -47,7 +50,7 @@ class ProjectionData(OrbitalData, ArrayData):
         # The [0:2] is so that each array, and not collection of arrays
         # is used to make the comparison
         if np.shape(projection_array) != shape_bands:
-            raise AttributeError('These arrays are not the same shape as' ' the bands')
+            raise AttributeError('These arrays are not the same shape as the bands')
 
     def set_reference_bandsdata(self, value):
         """
@@ -73,12 +76,10 @@ class ProjectionData(OrbitalData, ArrayData):
                     uuid = bands.uuid
                 except Exception:  # pylint: disable=bare-except
                     raise exceptions.NotExistent(
-                        'The value passed to '
-                        'set_reference_bandsdata was not '
-                        'associated to any bandsdata'
+                        'The value passed to set_reference_bandsdata was not associated to any bandsdata'
                     )
 
-        self.set_attribute('reference_bandsdata_uuid', uuid)
+        self.base.attributes.set('reference_bandsdata_uuid', uuid)
 
     def get_reference_bandsdata(self):
         """
@@ -91,7 +92,7 @@ class ProjectionData(OrbitalData, ArrayData):
         """
         from aiida.orm import load_node
         try:
-            uuid = self.get_attribute('reference_bandsdata_uuid')
+            uuid = self.base.attributes.get('reference_bandsdata_uuid')
         except AttributeError:
             raise AttributeError('BandsData has not been set for this instance')
         try:
@@ -218,7 +219,7 @@ class ProjectionData(OrbitalData, ArrayData):
             required_length, raises exception using array_name if there is
             a failure
             """
-            if not all([isinstance(_, np.ndarray) for _ in array_list]):
+            if not all(isinstance(_, np.ndarray) for _ in array_list):
                 raise exceptions.ValidationError(f'{array_name} was not composed entirely of ndarrays')
             if len(array_list) != orb_length:
                 raise exceptions.ValidationError(f'{array_name} did not have the same length as the list of orbitals')
@@ -247,7 +248,7 @@ class ProjectionData(OrbitalData, ArrayData):
             cls = OrbitalFactory(orbital_type)
             test_orbital = cls(**orbital_dict)
             list_of_orbital_dicts.append(test_orbital.get_orbital_dict())
-        self.set_attribute('orbital_dicts', list_of_orbital_dicts)
+        self.base.attributes.set('orbital_dicts', list_of_orbital_dicts)
 
         # verifies and sets the projections
         if list_of_projections:
@@ -283,9 +284,9 @@ class ProjectionData(OrbitalData, ArrayData):
             except IndexError:
                 return exceptions.ValidationError('tags must be a list')
 
-            if not all([isinstance(_, str) for _ in tags]):
+            if not all(isinstance(_, str) for _ in tags):
                 raise exceptions.ValidationError('Tags must set a list of strings')
-            self.set_attribute('tags', tags)
+            self.base.attributes.set('tags', tags)
 
     def set_orbitals(self, **kwargs):  # pylint: disable=arguments-differ
         """
