@@ -86,7 +86,7 @@ class Code(AbstractCode):
         type_check(computer, orm.Computer)
         return computer.pk == self.get_remote_computer().pk
 
-    def get_executable(self) -> pathlib.Path:
+    def get_executable(self) -> pathlib.PurePosixPath:
         """Return the executable that the submission script should execute to run the code.
 
         :return: The executable to be called in the submission script.
@@ -96,7 +96,7 @@ class Code(AbstractCode):
         else:
             exec_path = self.get_remote_exec_path()
 
-        return pathlib.Path(exec_path)
+        return pathlib.PurePosixPath(exec_path)
 
     def hide(self):
         """
@@ -140,16 +140,17 @@ class Code(AbstractCode):
                     self.base.repository.put_object_from_filelike(handle, os.path.split(filename)[1])
 
     def __str__(self):
-        local_str = 'Local' if self.is_local() else 'Remote'
-        computer_str = self.computer.label
-        return f"{local_str} code '{self.label}' on {computer_str}, pk: {self.pk}, uuid: {self.uuid}"
+        if self.computer is None:
+            return f"Local code '{self.label}' pk: {self.pk}, uuid: {self.uuid}"
+
+        return f"Remote code '{self.label}' on {self.computer.label} pk: {self.pk}, uuid: {self.uuid}"
 
     def get_computer_label(self):
         """Get label of this code's computer."""
         warn_deprecation(
             'This method is deprecated, use the `InstalledCode.computer.label` property instead.', version=3
         )
-        return 'repository' if self.is_local() else self.computer.label
+        return 'repository' if self.computer is None else self.computer.label
 
     @property
     def full_label(self):
@@ -157,7 +158,7 @@ class Code(AbstractCode):
 
         Returns label of the form <code-label>@<computer-name>.
         """
-        return f'{self.label}@{"repository" if self.is_local() else self.computer.label}'
+        return f'{self.label}@{"repository" if self.computer is None else self.computer.label}'
 
     def relabel(self, new_label):
         """Relabel this code.
@@ -165,10 +166,10 @@ class Code(AbstractCode):
         :param new_label: new code label
         """
         warn_deprecation('This method is deprecated, use the `label` property instead.', version=3)
-        # pylint: disable=unused-argument
-        suffix = f'@{self.computer.label}'
-        if new_label.endswith(suffix):
-            new_label = new_label[:-len(suffix)]
+        if self.computer is not None:
+            suffix = f'@{self.computer.label}'
+            if new_label.endswith(suffix):
+                new_label = new_label[:-len(suffix)]
 
         self.label = new_label
 
@@ -205,11 +206,15 @@ class Code(AbstractCode):
         elif query.count() > 1:
             codes = query.all(flat=True)
             retstr = f"There are multiple codes with label '{label}', having IDs: "
-            retstr += f"{', '.join(sorted([str(c.pk) for c in codes]))}.\n"
+            retstr += f"{', '.join(sorted([str(c.pk) for c in codes]))}.\n"  # type: ignore[union-attr]
             retstr += ('Relabel them (using their ID), or refer to them with their ID.')
             raise MultipleObjectsError(retstr)
         else:
-            return query.first()[0]
+            result = query.first()
+            if not result:
+                raise NotExistent(f"code '{label}' does not exist.")
+
+            return result[0]
 
     @classmethod
     def get(cls, pk=None, label=None, machinename=None):
@@ -303,9 +308,9 @@ class Code(AbstractCode):
         valid_codes = query.all(flat=True)
 
         if labels:
-            return [c.label for c in valid_codes]
+            return [c.label for c in valid_codes]  # type: ignore[union-attr]
 
-        return [c.pk for c in valid_codes]
+        return [c.pk for c in valid_codes]  # type: ignore[union-attr]
 
     def _validate(self):
         super()._validate()
@@ -347,6 +352,9 @@ class Code(AbstractCode):
         )
         filepath = self.get_remote_exec_path()
 
+        if self.computer is None:
+            raise exceptions.ValidationError('checking the remote exec path is not available for a local code.')
+
         try:
             with override_log_level():  # Temporarily suppress noisy logging
                 with self.computer.get_transport() as transport:
