@@ -83,7 +83,7 @@ class EnumData(Data):
         except ValueError as exc:
             raise ImportError(f'Could not reconstruct enum class because `{identifier}` could not be loaded.') from exc
 
-    def get_member(self) -> EnumType:
+    def get_member(self) -> EnumType:  # type: ignore
         """Return the enum member reconstructed from the serialized data stored in the database.
 
         For the enum member to be successfully reconstructed, the class of course has to still be importable and its
