@@ -10,8 +10,9 @@
 """Data plugin to model an atomic orbital."""
 import copy
 
-from aiida.common.exceptions import ValidationError, InputValidationError
+from aiida.common.exceptions import ValidationError
 from aiida.plugins import OrbitalFactory
+
 from .data import Data
 
 __all__ = ('OrbitalData',)
@@ -28,7 +29,7 @@ class OrbitalData(Data):
         Remove all orbitals that were added to the class
         Cannot work if OrbitalData has been already stored
         """
-        self.set_attribute('orbital_dicts', [])
+        self.base.attributes.set('orbital_dicts', [])
 
     def get_orbitals(self, **kwargs):
         """
@@ -42,15 +43,15 @@ class OrbitalData(Data):
         :return list_of_outputs: a list of orbitals
         """
 
-        orbital_dicts = copy.deepcopy(self.get_attribute('orbital_dicts', None))
+        orbital_dicts = copy.deepcopy(self.base.attributes.get('orbital_dicts', None))
         if orbital_dicts is None:
             raise AttributeError('Orbitals must be set before being retrieved')
 
         filter_dict = {}
         filter_dict.update(kwargs)
         # prevents KeyError from occuring
-        orbital_dicts = [x for x in orbital_dicts if all([y in x for y in filter_dict])]
-        orbital_dicts = [x for x in orbital_dicts if all([x[y] == filter_dict[y] for y in filter_dict])]
+        orbital_dicts = [x for x in orbital_dicts if all(y in x for y in filter_dict)]
+        orbital_dicts = [x for x in orbital_dicts if all(x[y] == z for y, z in filter_dict.items())]
 
         list_of_outputs = []
         for orbital_dict in orbital_dicts:
@@ -80,9 +81,9 @@ class OrbitalData(Data):
             try:
                 _orbital_type = orbital_dict['_orbital_type']
             except KeyError:
-                raise InputValidationError(f'No _orbital_type found in: {orbital_dict}')
+                raise ValueError(f'No _orbital_type found in: {orbital_dict}')
             orbital_dicts.append(orbital_dict)
-        self.set_attribute('orbital_dicts', orbital_dicts)
+        self.base.attributes.set('orbital_dicts', orbital_dicts)
 
 
 ##########################################################################
