@@ -35,7 +35,7 @@ from .links import NodeLinks
 from .repository import NodeRepository
 
 if TYPE_CHECKING:
-    from aiida.plugins.entry_point import EntryPoint
+    from aiida.plugins.entry_point import EntryPoint  # type: ignore
 
     from ..implementation import BackendNode, StorageBackend
 
@@ -128,7 +128,7 @@ class NodeBase:
         return self._node._CLS_NODE_LINKS(self._node)  # pylint: disable=protected-access
 
 
-class Node(Entity['BackendNode'], metaclass=AbstractNodeMeta):
+class Node(Entity['BackendNode', NodeCollection], metaclass=AbstractNodeMeta):
     """
     Base class for all nodes in AiiDA.
 
@@ -182,14 +182,14 @@ class Node(Entity['BackendNode'], metaclass=AbstractNodeMeta):
         if computer and not computer.is_stored:
             raise ValueError('the computer is not stored')
 
-        computer = computer.backend_entity if computer else None
+        backend_computer = computer.backend_entity if computer else None
         user = user if user else backend.default_user
 
         if user is None:
             raise ValueError('the user cannot be None')
 
         backend_entity = backend.nodes.create(
-            node_type=self.class_node_type, user=user.backend_entity, computer=computer, **kwargs
+            node_type=self.class_node_type, user=user.backend_entity, computer=backend_computer, **kwargs
         )
         super().__init__(backend_entity)
 
