@@ -8,8 +8,8 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Manage computer objects with lazy loading of the db env"""
-
 from aiida.cmdline.utils.decorators import with_dbenv
+from aiida.common.exceptions import ValidationError
 from aiida.common.utils import ErrorAccumulator
 
 
@@ -39,12 +39,14 @@ class ComputerBuilder:  # pylint: disable=too-many-instance-attributes
         spec['hostname'] = computer.hostname
         spec['scheduler'] = computer.scheduler_type
         spec['transport'] = computer.transport_type
+        spec['use_double_quotes'] = computer.get_use_double_quotes()
         spec['prepend_text'] = computer.get_prepend_text()
         spec['append_text'] = computer.get_append_text()
         spec['work_dir'] = computer.get_workdir()
         spec['shebang'] = computer.get_shebang()
         spec['mpirun_command'] = ' '.join(computer.get_mpirun_command())
         spec['mpiprocs_per_machine'] = computer.get_default_mpiprocs_per_machine()
+        spec['default_memory_per_machine'] = computer.get_default_memory_per_machine()
 
         return spec
 
@@ -75,6 +77,7 @@ class ComputerBuilder:  # pylint: disable=too-many-instance-attributes
         computer.description = self._get_and_count('description', used)
         computer.scheduler_type = self._get_and_count('scheduler', used)
         computer.transport_type = self._get_and_count('transport', used)
+        computer.set_use_double_quotes(self._get_and_count('use_double_quotes', used))
         computer.set_prepend_text(self._get_and_count('prepend_text', used))
         computer.set_append_text(self._get_and_count('append_text', used))
         computer.set_workdir(self._get_and_count('work_dir', used))
@@ -99,6 +102,19 @@ class ComputerBuilder:  # pylint: disable=too-many-instance-attributes
                 )
             computer.set_default_mpiprocs_per_machine(mpiprocs_per_machine)
 
+        def_memory_per_machine = self._get_and_count('default_memory_per_machine', used)
+        if def_memory_per_machine is not None:
+            try:
+                def_memory_per_machine = int(def_memory_per_machine)
+            except ValueError:
+                raise self.ComputerValidationError(
+                    'Invalid value provided for memory_per_machine, must be a valid integer'
+                )
+            try:
+                computer.set_default_memory_per_machine(def_memory_per_machine)
+            except ValidationError as exception:
+                raise self.ComputerValidationError(f'Invalid value for `default_memory_per_machine`: {exception}')
+
         mpirun_command_internal = self._get_and_count('mpirun_command', used).strip().split(' ')
         if mpirun_command_internal == ['']:
             mpirun_command_internal = []
