@@ -12,12 +12,10 @@ Contain utility classes for "managers", i.e., classes that allow
 to access members of other classes via TAB-completable attributes
 (e.g. the class underlying `calculation.inputs` to allow to do `calculation.inputs.<label>`).
 """
-import warnings
-
 from aiida.common import AttributeDict
-from aiida.common.links import LinkType
 from aiida.common.exceptions import NotExistent, NotExistentAttributeError, NotExistentKeyError
-from aiida.common.warnings import AiidaDeprecationWarning
+from aiida.common.links import LinkType
+from aiida.common.warnings import warn_deprecation
 
 __all__ = ('NodeLinksManager', 'AttributeManager')
 
@@ -56,9 +54,9 @@ class NodeLinksManager:
         :param incoming: if True, inspect incoming links, otherwise inspect outgoing links.
         """
         if incoming:
-            links = self._node.get_incoming(link_type=self._link_type)
+            links = self._node.base.links.get_incoming(link_type=self._link_type)
         else:
-            links = self._node.get_outgoing(link_type=self._link_type)
+            links = self._node.base.links.get_outgoing(link_type=self._link_type)
 
         return AttributeDict(links.nested())
 
@@ -100,11 +98,11 @@ class NodeLinksManager:
                 not (label.startswith(self._namespace_separator) and label.endswith(self._namespace_separator))
             ):
                 import functools
-                warnings.warn(
+                warn_deprecation(
                     'dereferencing nodes with links containing double underscores is deprecated, simply replace '
                     'the double underscores with a single dot instead. For example: \n'
-                    '`self.inputs.some__label` can be written as `self.inputs.some.label` instead.\n'
-                    'Support for double underscores will be removed in the future.', AiidaDeprecationWarning
+                    '`self.inputs.some__label` can be written as `self.inputs.some.label` instead.\n',
+                    version=3
                 )  # pylint: disable=no-member
                 namespaces = label.split(self._namespace_separator)
                 try:
@@ -151,10 +149,10 @@ class NodeLinksManager:
     def __contains__(self, key):
         """Override the operator of the base class to emit deprecation warning if double underscore is used in key."""
         if self._namespace_separator in key:
-            warnings.warn(
+            warn_deprecation(
                 'The use of double underscores in keys is deprecated. Please expand the namespaces manually:\n'
                 'instead of `nested__key in node.inputs`, use `nested in node.inputs and `key in node.inputs.nested`.',
-                AiidaDeprecationWarning
+                version=3
             )
             namespaces = key.split(self._namespace_separator)
             leaf = namespaces.pop()
@@ -210,7 +208,7 @@ class AttributeManager:
         """
         # Possibly add checks here
         # We cannot set `self._node` because it would go through the __setattr__ method
-        # which uses said _node by calling `self._node.set_attribute(name, value)`.
+        # which uses said _node by calling `self._node.base.attributes.set(name, value)`.
         # Instead, we need to manually set it through the `self.__dict__` property.
         self.__dict__['_node'] = node
 
@@ -218,20 +216,20 @@ class AttributeManager:
         """
         Allow to list the keys of the dictionary
         """
-        return sorted(self._node.attributes_keys())
+        return sorted(self._node.base.attributes.keys())
 
     def __iter__(self):
         """
         Return the keys as an iterator
         """
-        for k in self._node.attributes_keys():
+        for k in self._node.base.attributes.keys():
             yield k
 
     def _get_dict(self):
         """
         Return the internal dictionary
         """
-        return dict(self._node.attributes_items())
+        return dict(self._node.base.attributes.items())
 
     def __getattr__(self, name):
         """
@@ -242,10 +240,10 @@ class AttributeManager:
 
         :param name: name of the key whose value is required.
         """
-        return self._node.get_attribute(name)
+        return self._node.base.attributes.get(name)
 
     def __setattr__(self, name, value):
-        self._node.set_attribute(name, value)
+        self._node.base.attributes.set(name, value)
 
     def __getitem__(self, name):
         """
@@ -254,6 +252,6 @@ class AttributeManager:
         :param name: name of the key whose value is required.
         """
         try:
-            return self._node.get_attribute(name)
+            return self._node.base.attributes.get(name)
         except AttributeError as exception:
             raise KeyError(str(exception)) from exception
