@@ -13,6 +13,7 @@ This has been tested on PBSPro v. 12.
 """
 
 import logging
+
 from .pbsbaseclasses import PbsBaseClass
 
 _LOGGER = logging.getLogger(__name__)
@@ -90,11 +91,7 @@ class PbsproScheduler(PbsBaseClass):
                 if physical_memory_kb <= 0:
                     raise ValueError
             except ValueError:
-                raise ValueError(
-                    'max_memory_kb must be '
-                    "a positive integer (in kB)! It is instead '{}'"
-                    ''.format((max_memory_kb))
-                )
+                raise ValueError(f'max_memory_kb must be a positive integer (in kB)! It is instead `{max_memory_kb}`')
             select_string += f':mem={physical_memory_kb}kb'
 
         return_lines.append(f'#PBS -l {select_string}')
