@@ -10,19 +10,18 @@
 """
 Defines an rst directive to auto-document AiiDA processes.
 """
-from collections.abc import Mapping, Iterable
+from collections.abc import Iterable, Mapping
 import inspect
 
 from docutils import nodes
 from docutils.core import publish_doctree
 from docutils.parsers.rst import directives
+from plumpy.ports import OutputPort
 from sphinx import addnodes
 from sphinx.ext.autodoc import ClassDocumenter
 from sphinx.util.docutils import SphinxDirective
 from sphinxcontrib.details.directive import details, summary
 
-from plumpy.ports import OutputPort
-
 from aiida.common.utils import get_object_from_string
 from aiida.engine import Process
 from aiida.engine.processes.ports import InputPort, PortNamespace
