@@ -10,12 +10,12 @@
 """"Implementation of `DbImporter` for the MPDS database."""
 import copy
 import enum
+import json
 import os
 
 import requests
 
 from aiida.tools.dbimporters.baseclasses import CifEntry, DbEntry, DbImporter, DbSearchResults
-from aiida.common import json
 
 
 class ApiFormat(enum.Enum):
