@@ -33,8 +33,10 @@ Usage
 
    In [2]: %aiida
 """
+import json
+import shlex
 
-from IPython import version_info, get_ipython
+from IPython import get_ipython, version_info
 from IPython.core import magic
 
 
@@ -61,6 +63,18 @@ def add_to_ns(local_ns, name, obj):
 class AiiDALoaderMagics(magic.Magics):
     """AiiDA magic loader."""
 
+    @magic.needs_local_scope
+    @magic.line_magic
+    def verdi(self, line='', local_ns=None):  # pylint: disable=no-self-use,unused-argument
+        """Run the AiiDA command line tool, using the currently loaded configuration and profile."""
+        from aiida.cmdline.commands.cmd_verdi import verdi
+        from aiida.common import AttributeDict
+        from aiida.manage import get_config, get_profile
+        config = get_config()
+        profile = get_profile()
+        obj = AttributeDict({'config': config, 'profile': profile})
+        return verdi(shlex.split(line), prog_name='%verdi', obj=obj, standalone_mode=False)  # pylint: disable=too-many-function-args,unexpected-keyword-arg
+
     @magic.needs_local_scope
     @magic.line_magic
     def aiida(self, line='', local_ns=None):
@@ -75,8 +89,8 @@ class AiiDALoaderMagics(magic.Magics):
         .. todo:: implement parameters, e.g. for the profile to load.
         """
         # pylint: disable=unused-argument,attribute-defined-outside-init
-        from aiida.manage.configuration import load_profile
         from aiida.cmdline.utils.shell import get_start_namespace
+        from aiida.manage.configuration import load_profile
 
         self.is_warning = False
         lcontent = line.strip()
@@ -97,8 +111,6 @@ class AiiDALoaderMagics(magic.Magics):
         """
         Output in JSON format.
         """
-        from aiida.common import json
-
         obj = {'current_state': self.current_state}
         if version_info[0] >= 3:
             return obj
